==> haskell-casa-types-0.0.2-531-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-IvbygSNO0S2KIlfQSg9bjZ
key:                  casa-types-0.0.2-IvbygSNO0S2KIlfQSg9bjZ
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  6a2a081352eb626aea91a65091b35b13
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.2-IvbygSNO0S2KIlfQSg9bjZ
depends:
    aeson-2.1.2.1-3ASKPK4Fa4QIZhzaxHwjxs
    attoparsec-0.14.4-JZZdD0OB179Gbus6hPxtF7 base-4.17.2.1
    base16-bytestring-1.0.2.0-EhkcVfgjuwAFVcx9XSm9uN
    bytestring-0.11.5.3 hashable-1.4.4.0-LeeIMVjvAfZ9pPDINFzJD3
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-GvGSHxB04htDrKXOlQOKyX text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-types-0.0.2-532-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-types
version:              0.0.2
visibility:           public
id:                   casa-types-0.0.2-23eNAZZhVfhEgDQ4daTSpM
key:                  casa-types-0.0.2-23eNAZZhVfhEgDQ4daTSpM
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Types for Casa
description:          Types for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  46c3f44af1c7786a16cd4ac099706d6c
exposed:              True
exposed-modules:      Casa.Types
hidden-modules:       Paths_casa_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/casa-types-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-types
hs-libraries:         HScasa-types-0.0.2-23eNAZZhVfhEgDQ4daTSpM
depends:
    aeson-2.1.2.1-3ASKPK4Fa4QIZhzaxHwjxs
    attoparsec-0.14.4-JZZdD0OB179Gbus6hPxtF7 base-4.17.2.1
    base16-bytestring-1.0.2.0-EhkcVfgjuwAFVcx9XSm9uN
    bytestring-0.11.5.3 hashable-1.4.4.0-LeeIMVjvAfZ9pPDINFzJD3
    path-pieces-0.2.1-3XB1w9Pq9G55ySSfgWLsAv
    persistent-2.14.5.1-9Xbyg59v2JJH1v2ZrVBkEb text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-casa-types/html/casa-types.haddock
haddock-html:         /usr/share/doc/haskell-casa-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
